@@ -80,7 +80,7 @@ class SemanticSegmentationPathsDataSource(PathsDataSource):
 
     def __init__(self):
         if not _IMAGE_AVAILABLE:
-            raise ModuleNotFoundError("Please, pip install -e '.[image]'")
+            raise ModuleNotFoundError("Please, pip install 'lightning-flash[image]'")
         super().__init__(IMG_EXTENSIONS)
 
     def load_data(self, data: Union[Tuple[str, str], Tuple[List[str], List[str]]],
@@ -172,7 +172,7 @@ class SemanticSegmentationPreprocess(Preprocess):
             image_size: A tuple with the expected output image size.
         """
         if not _IMAGE_AVAILABLE:
-            raise ModuleNotFoundError("Please, pip install -e '.[image]'")
+            raise ModuleNotFoundError("Please, pip install 'lightning-flash[image]'")
         self.image_size = image_size
         self.num_classes = num_classes
         if num_classes:
